@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-dynamodb-seeder",
-    "1.0.9",
+    "1.0.11",
     __name__[0:-6],
-    "cdk-dynamodb-seeder@1.0.9.jsii.tgz",
+    "cdk-dynamodb-seeder@1.0.11.jsii.tgz",
 )
 
 __all__ = [
